changeset 494:6e9c1ea44262

Increase timer for the test
author Sebastien Decugis <sdecugis@nict.go.jp>
date Mon, 16 Aug 2010 11:43:55 +0900
parents 2577514b2546
children 6e53be78d658
files freeDiameter/tests/testfifo.c
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/freeDiameter/tests/testfifo.c	Thu Aug 12 15:57:52 2010 +0900
+++ b/freeDiameter/tests/testfifo.c	Mon Aug 16 11:43:55 2010 +0900
@@ -211,7 +211,7 @@
 		
 		/* Initialize the ts */
 		CHECK(0, clock_gettime(CLOCK_REALTIME, &ts));
-		ts.tv_sec += 2; /* Set the timeout to 2 second */
+		ts.tv_sec += 20; /* Set the timeout to 20 second */
 		
 		/* Create the messages */
 		CHECK( 0, fd_dict_search ( fd_g_config->cnf_dict, DICT_COMMAND, CMD_BY_NAME, "Device-Watchdog-Request",		&dwr_model, ENOENT ) );
@@ -281,7 +281,7 @@
 		
 		/* Initialize the ts */
 		CHECK(0, clock_gettime(CLOCK_REALTIME, &ts));
-		ts.tv_sec += 2; /* Set the timeout to 2 second */
+		ts.tv_sec += 10; /* Set the timeout to 10 second */
 		
 		/* Initialize the test data structures */
 		td.queue = queue;
"Welcome to our mercurial repository"